@@ -198,9 +198,9 @@ def _set_taskid_in_db_key(result: AsyncResult, db, db_key):
 
 
 class DictWillNotAllowWrites(dict):
-    def __init__(self, *args, _instrumentation_context=None, **kwargs):
+    def __init__(self, _instrumentation_context=None, **kwargs):
         self.context = _instrumentation_context
-        super().__init__(*args, **kwargs)
+        super().__init__(**kwargs)
 
     def warn(self):
         if self.context:
@@ -223,6 +223,26 @@ class DictWillNotAllowWrites(dict):
         self.warn()
         super().__delitem__(*args, **kwargs)
 
+    def pop(self, *args, **kwargs):
+        self.warn()
+        return super().pop(*args, **kwargs)
+
+    def popitem(self):
+        self.warn()
+        return super().popitem()
+
+    def clear(self):
+        self.warn()
+        super().clear()
+
+    def setdefault(self, *args, **kwargs):
+        self.warn()
+        return super().setdefault(*args, **kwargs)
+
+    def update(self, *args, **kwargs):
+        self.warn()
+        super().update(*args, **kwargs)
+
 
 class FireXTask(Task):
     """
@@ -337,11 +357,13 @@ class FireXTask(Task):
         self.context.enqueued_children = {}
         self.context.bog = None
 
-        # Favour @app.task(flame=...) driven-style when present over @flame() annotation style.
         # Flame configs need to be on self.context b/c they write to flame_data_configs[k]['on_next'] for collapse ops.
         # Might make more sense to rework that to avoid flame data on context.
-        self.context.flame_configs = self.get_task_flame_configs() or deepcopy(getattr(self.undecorated,
-                                                                                       "flame_data_configs", {}))
+        self.context.flame_configs = (
+            deepcopy(getattr(self.undecorated, "flame_data_configs", {}))
+            # Overwrite @app.task(flame=...) driven-style when present over @flame() annotation style.
+            | self.get_task_flame_configs()
+        )
 
     def get_module_file_location(self):
         return sys.modules[self.__module__].__file__
@@ -784,7 +806,7 @@ class FireXTask(Task):
 
     @property
     def abog(self) -> DictWillNotAllowWrites:
-        return DictWillNotAllowWrites(_instrumentation_context=self, **self.bag, **self.default_bound_args)
+        return DictWillNotAllowWrites(_instrumentation_context=self, **{**self.bag, **self.default_bound_args})
 
     #######################
     # Enqueuing child tasks
@@ -1057,7 +1079,7 @@ class FireXTask(Task):
                                                **kwargs)
 
     def enqueue_in_parallel(self, chains, max_parallel_chains=15, wait_for_completion=True,
-                            raise_exception_on_failure=False):
+                            raise_exception_on_failure=False, **kwargs):
         """ This method executes the provided list of Signatures/Chains in parallel
         and returns the associated list of "async_result" objects.
         The results are returned in the same order as the input Signatures/Chains."""
@@ -1070,7 +1092,7 @@ class FireXTask(Task):
                 scheduled.remove(async_res)
             # Schedule the next child
             logger.debug(f'Enqueueing: {c.get_label()}')
-            promise = self.enqueue_child(c)
+            promise = self.enqueue_child(c, **kwargs)
             scheduled.append(promise)
             promises.append(promise)
         if wait_for_completion or raise_exception_on_failure:
